Function for measure information loss by shannon information entropy.
Usage
F_informationloss(xvar, xdisc)
Arguments
- xvar
The original undiscretized vector.
- xdisc
The discretized vector.
Value
A numeric value of information loss measured by information entropy.
Details
The information loss measured by information entropy formula is
\(F = -\sum\limits_{i=1}^N p_{(i)}\log_2 p_{(i)} - \left(-\sum\limits_{h=1}^L p_{(h)}\log_2 p_{(h)}\right)\)
Examples
F_informationloss(1:7,c('x',rep('y',3),rep('z',3)))
#> [1] 1.358539