S3 method to plot output for ecological detector in geodetector().
Usage
# S3 method for class 'ecological_detector'
plot(x, ...)Arguments
- x
Return by
geodetector().- ...
(optional) Other arguments passed to
ggplot2::theme().
S3 method to plot output for ecological detector in geodetector().
# S3 method for class 'ecological_detector'
plot(x, ...)Return by geodetector().
(optional) Other arguments passed to ggplot2::theme().