S3 method to format output for gozh sesu from sesu_gozh().
Usage
# S3 method for class 'sesu_gozh'
print(x, ...)Arguments
- x
Return by
sesu_gozh().- ...
(optional) Other arguments passed to
knitr::kable().
S3 method to format output for gozh sesu from sesu_gozh().
# S3 method for class 'sesu_gozh'
print(x, ...)Return by sesu_gozh().
(optional) Other arguments passed to knitr::kable().